<?php

/**
 * Copyright distrib (2018)
 *
 * contact@opendistrib.net
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace common\logic\Subscription\Subscription\Model;

use common\components\ActiveRecordCommon;
use common\logic\PointSale\PointSale\Model\PointSale;
use common\logic\Producer\Producer\Model\Producer;
use common\logic\Subscription\ProductSubscription\Model\ProductSubscription;
use common\logic\User\User\Model\User;

class Subscription extends ActiveRecordCommon
{
    const AUTO_PAYMENT_DEDUCTED = 1;
    const AUTO_PAYMENT_YES = 2;
    const AUTO_PAYMENT_NO = 0;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return 'subscription';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id_producer', 'id_point_sale'], 'required'],
            [['id_user', 'id_producer', 'id_point_sale', 'monday', 'tuesday',
                'wednesday', 'thursday', 'friday', 'saturday', 'sunday',
                'week_frequency', 'auto_payment', 'id_created_by', 'id_updated_by'], 'integer'],
            [['created_at', 'updated_at'], 'datetime', 'format' => 'php:Y-m-d H:i:s'],
            [['username', 'comment', 'date_begin', 'date_end'], 'safe'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'id_user' => 'Utilisateur',
            'id_producer' => 'Etablissement',
            'id_point_sale' => 'Point de vente',
            'date_begin' => 'Date de début',
            'date_end' => 'Date de fin',
            'monday' => 'Lundi',
            'tuesday' => 'Mardi',
            'wednesday' => 'Mercredi',
            'thursday' => 'Jeudi',
            'friday' => 'Vendredi',
            'saturday' => 'Samedi',
            'sunday' => 'Dimanche',
            'week_frequency' => 'Périodicité',
            'auto_payment' => 'Débit automatique',
            'comment' => 'Commentaire',
            'created_at' => 'Création',
            'updated_at' => 'Modification',
            'created_by' => 'Créé par',
            'updated_by' => 'Modifié par',
        ];
    }

    /*
     * Relations
     */

    public function getUser()
    {
        return $this->hasOne(User::class, ['id' => 'id_user']);
    }

    public function populateUser(User $user): void
    {
        $this->populateFieldObject('id_user', 'user', $user);
    }

    public function getProducer()
    {
        return $this->hasOne(Producer::class, ['id' => 'id_producer']);
    }

    public function populateProducer(Producer $producer): void
    {
        $this->populateFieldObject('id_producer', 'producer', $producer);
    }

    public function getPointSale()
    {
        return $this->hasOne(PointSale::class, ['id' => 'id_point_sale']);
    }

    public function populatePointSale(PointSale $pointSale): void
    {
        $this->populateFieldObject('id_point_sale', 'pointSale', $pointSale);
    }

    public function getProductSubscription()
    {
        return $this->hasMany(ProductSubscription::class, ['id_subscription' => 'id'])
            ->with('product');
    }

    public function getCreatedBy()
    {
        return $this->hasOne(User::class, ['id' => 'id_created_by']);
    }

    public function populateCreatedBy(User $createdBy): void
    {
        $this->populateFieldObject('id_created_by', 'createdBy', $createdBy);
        $this->created_at = date('Y-m-d H:i:s');
    }

    public function getUpdatedBy()
    {
        return $this->hasOne(User::class, ['id' => 'id_updated_by']);
    }

    public function populateUpdatedBy(User $updatedBy): void
    {
        $this->populateFieldObject('id_updated_by', 'updatedBy', $updatedBy);
        $this->updated_at = date('Y-m-d H:i:s');
    }
}
